# sparkutility
For functionalities that are missing in Spark SQL

## Available functions
- isNumeric <br/><br/>

## example
```
from sparkutility import is_numeric

print(is_numeric(40.2))
print(is_numeric('40.2a'))

'''
output:
True
False
'''
```
